Struct SqliteStoreConfig

pub struct SqliteStoreConfig { /* private fields */ }
A configuration structure used for opening a store.

Implementations

Source

impl SqliteStoreConfig

pub fn new<P>(path: P) -> Self
where P: AsRef<Path>,

Create a new SqliteStoreConfig with a path representing the directory containing the store database.

pub fn passphrase(self, passphrase: Option<&str>) -> Self

Define the passphrase if the store is encoded.

pub fn pool_max_size(self, max_size: usize) -> Self

Define the maximum pool size for deadpool_sqlite.

See deadpool_sqlite::PoolConfig::max_size to learn more.

pub fn optimize(self, optimize: bool) -> Self

Optimize the database.

The SQLite documentation recommends to run this regularly and after any schema change. The easiest is to do it consistently when the store is constructed, after eventual migrations.

See [PRAGMA optimize] to learn more.

The default value is true.

pub fn cache_size(self, cache_size: u32) -> Self

Define the maximum size in bytes the SQLite cache can use.

See PRAGMA cache_size to learn more.

The default value is 2Mib.

pub fn journal_size_limit(self, limit: u32) -> Self

Limit the size of the WAL file, in bytes.

By default, while the DB connections of the databases are open, the size of the WAL file can keep increasing depending on the size needed for the transactions. A critical case is VACUUM which basically writes the content of the DB file to the WAL file before writing it back to the DB file, so we end up taking twice the size of the database.

By setting this limit, the WAL file is truncated after its content is written to the database, if it is bigger than the limit.

See PRAGMA journal_size_limit to learn more. The value limit corresponds to N in PRAGMA journal_size_limit = N.

The default value is 10Mib.